au BufRead,BufNewFile *_list  set filetype=espeaklist fileencoding=utf-8 fileformat=unix
au BufRead,BufNewFile *_listx set filetype=espeaklist fileencoding=utf-8 fileformat=unix
au BufRead,BufNewFile *_extra set filetype=espeaklist fileencoding=utf-8 fileformat=unix
au BufRead,BufNewFile *_emoji set filetype=espeaklist fileencoding=utf-8 fileformat=unix
au BufRead,BufNewFile *_rules set filetype=espeakrules fileencoding=utf-8 fileformat=unix
